@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 #  Licensed under the Apache License, Version 2.0 (the "License"); you may
 #  not use this file except in compliance with the License. You may obtain
@@ -12,17 +11,21 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
-import testtools
+import testtools  # type: ignore
 
 import fixtures
 
 
 class TestBase(testtools.TestCase):
     def setUp(self):
-        super(TestBase, self).setUp()
+        super().setUp()
+
         self._stdout_fixture = fixtures.StringStream('stdout')
         self.stdout = self.useFixture(self._stdout_fixture).stream
         self.useFixture(fixtures.MonkeyPatch('sys.stdout', self.stdout))
+
         self._stderr_fixture = fixtures.StringStream('stderr')
         self.stderr = self.useFixture(self._stderr_fixture).stream
         self.useFixture(fixtures.MonkeyPatch('sys.stderr', self.stderr))
+
+        self.logger = self.useFixture(fixtures.FakeLogger('cliff'))
